@@ -202,7 +202,7 @@ class between(ApiviewDecorator):
         else:
             max_value = max
         value = _django_apiview_request.data.get(field, None)
-        value = typingutils.smart_cast(typingutils.Number, value)
+        value = typingutils.smart_cast(self.annotation, value)
         if (allow_none and value is None) or ((include_min and min_value <= value or min_value < value) and (include_max and max_value >= value or max_value > value)):
             return super().main(_django_apiview_request, func)
         else:
